==> buildbot_4.0.2.orig.tar.gz: buildbot-4.0.2/www/base/src/plugins/GlobalSetup.ts <==
/*
  This file is part of Buildbot.  Buildbot is free software: you can
  redistribute it and/or modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation, version 2.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

  Copyright Buildbot Team Members
*/

import {
  GroupSettings,
  registerPluginRegistrationConsumer,
  RegistrationCallbacks,
  RouteConfig,
  SettingGroupConfig
} from "buildbot-plugin-support";
import {Config} from "buildbot-ui";
import {globalMenuSettings} from "./GlobalMenuSettings";
import {globalRoutes} from "./GlobalRoutes";
import {globalSettings} from "./GlobalSettings";

export function initializeGlobalSetup(config: Config) {
  const onBuildbotSetupPlugin = (callback: (registrationCallbacks: RegistrationCallbacks, config: Config) => void) => {
    callback({
      registerMenuGroup: (group: GroupSettings) => { globalMenuSettings.addGroup(group); },
      registerRoute: (route: RouteConfig) => { globalRoutes.addRoute(route); },
      registerSettingGroup: (group: SettingGroupConfig) => { globalSettings.addGroup(group); },
    }, config);
  }
  registerPluginRegistrationConsumer(onBuildbotSetupPlugin);
}

==> buildbot_4.3.0.orig.tar.gz: buildbot-4.3.0/www/base/src/plugins/GlobalSetup.ts <==
/*
  This file is part of Buildbot.  Buildbot is free software: you can
  redistribute it and/or modify it under the terms of the GNU General Public
  License as published by the Free Software Foundation, version 2.

  This program is distributed in the hope that it will be useful, but WITHOUT
  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
  FOR A PARTICULAR PURPOSE.  See the GNU General Public License for more
  details.

  You should have received a copy of the GNU General Public License along with
  this program; if not, write to the Free Software Foundation, Inc., 51
  Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

  Copyright Buildbot Team Members
*/

import {
  GroupSettings,
  registerPluginRegistrationConsumer,
  RegistrationCallbacks,
  RouteConfig,
  SettingGroupConfig
} from "buildbot-plugin-support";
import {Config} from "buildbot-ui";
import {globalMenuSettings} from "./GlobalMenuSettings";
import {globalRoutes} from "./GlobalRoutes";
import {globalSettings} from "./GlobalSettings";

export function initializeGlobalSetup(config: Config) {
  const onBuildbotSetupPlugin = (callback: (registrationCallbacks: RegistrationCallbacks, config: Config) => void) => {
    callback({
      registerMenuGroup: (group: GroupSettings) => { globalMenuSettings.addGroup(group); },
      registerRoute: (route: RouteConfig) => { globalRoutes.addRoute(route); },
      registerSettingGroup: (group: SettingGroupConfig) => {
        globalSettings.addGroup(group);
        globalSettings.applyBuildbotConfig(config, group.name);
        globalSettings.load(group.name);
      },
    }, config);
  }
  registerPluginRegistrationConsumer(onBuildbotSetupPlugin);
}
